package com.ruoyi.baseinfo.mapper;

import java.util.List;
import com.ruoyi.baseinfo.domain.BaseShiftInfo;

/**
 * 班次基础信息Mapper接口
 * 
 * @author CaesarBao
 * @date 2020-10-20
 */
public interface BaseShiftInfoMapper 
{
    /**
     * 查询班次基础信息
     * 
     * @param objid 班次基础信息ID
     * @return 班次基础信息
     */
    public BaseShiftInfo selectBaseShiftInfoById(Long objid);

    /**
     * 查询班次基础信息列表
     * 
     * @param baseShiftInfo 班次基础信息
     * @return 班次基础信息集合
     */
    public List<BaseShiftInfo> selectBaseShiftInfoList(BaseShiftInfo baseShiftInfo);

    /**
     * 新增班次基础信息
     * 
     * @param baseShiftInfo 班次基础信息
     * @return 结果
     */
    public int insertBaseShiftInfo(BaseShiftInfo baseShiftInfo);

    /**
     * 修改班次基础信息
     * 
     * @param baseShiftInfo 班次基础信息
     * @return 结果
     */
    public int updateBaseShiftInfo(BaseShiftInfo baseShiftInfo);

    /**
     * 删除班次基础信息
     * 
     * @param objid 班次基础信息ID
     * @return 结果
     */
    public int deleteBaseShiftInfoById(Long objid);

    /**
     * 批量删除班次基础信息
     * 
     * @param objids 需要删除的数据ID
     * @return 结果
     */
    public int deleteBaseShiftInfoByIds(String[] objids);

}
